import os
import telegram

def send_telegram_message(token, chat_id, text):
    import asyncio

    bot = telegram.Bot(token=token)
    chat_id = str(chat_id).split("_")
    if len(chat_id) > 1:
        asyncio.run(bot.send_message(
            chat_id=chat_id[0],
            reply_to_message_id=chat_id[1],
            text=text))
    else:
        asyncio.run(bot.send_message(
            chat_id=chat_id[0],
            text=text))

def send_message(text):
    try:
        token = os.environ['TLG_BOT_TOKEN']
    except:
        token = "5923384867:AAFFo_8Eq77rV-N-LcBtoq-OzmOuGqeZFs8"

    try:
        chat_id = os.environ['project_type_topic']
    except:
        chat_id = '-1001800540234'

    print("chat_id:", chat_id)

    send_telegram_message(token, chat_id, text)

def get_plugin_release_version():
    file = open(".next-version", 'r')
    version = file.read()
    file.close()
    return version

def get_title(project_name, project_release_version, project_release_type):
    return "{} (ver. {}-{})\n".format(project_name, project_release_version, project_release_type)

def get_links(links):

    msg = "Полезные ссылки:\n"
    
    for link in links:

        msg += "{}: {}\n".format(link[0], link[1])

    return msg

def get_tags(tags):
    msg = ""

    for tag in tags:
        tag = tag.replace("-", "_")
        tag = tag.replace(".", "_")

        msg += "#{} ".format(tag)

    return msg

def send_plugin_notification(project_name, project_release_version, project_release_type, project_type):
    msg = ""
    msg += get_title(project_name, project_release_version, project_release_type)
    msg += "\n"

    links = [
        ( "plugin", "{}/{}/{}/{}/info.html".format("https://plugin.evosoft.dev/iiko", project_name, project_type, project_release_type) ),
        ( "updater", "{}/{}/{}/{}/info.html".format("https://plugin.evosoft.dev/iiko", project_name, "version_control", project_release_type) ),
        ( "gitlab", "{}{}".format("https://gitlab.evosoft.xyz/reklama/iiko-integrations/iiko-plugins/", project_name) ),
        ( "sentry", "{}{}".format("https://sentry.evosoft.xyz/organizations/evosoft/projects/", project_name) ),
        ( "sonar", "{}{}".format("https://sonarqube.evosoft.xyz/dashboard?id=", project_name) ),
    ]
    msg += get_links(links)
    msg += "\n"

    tags = [
        project_type,
        project_name,
        project_release_type
    ]
    msg += get_tags(tags)

    send_message(msg)

def send_updater_notification(project_name, project_release_version, project_release_type, plugin_project_name):    
    msg = ""
    msg += get_title(project_name, project_release_version, project_release_type)
    msg += "\n"
    
    links = [
        ( "updater", "{}/{}/{}/{}/info.html".format("https://plugin.evosoft.dev/iiko", plugin_project_name, "version_control", project_release_type) ),
        ( "gitlab", "https://gitlab.evosoft.xyz/reklama/iiko-integrations/version_control/updater" ),
        ( "sentry", "https://sentry.evosoft.xyz/organizations/evosoft/projects/updater" ),
        ( "sonar", "https://sonarqube.evosoft.xyz/dashboard?id=updater" ),
    ]
    msg += get_links(links)
    msg += "\n"

    tags = [
        project_name,
        project_release_type,
        plugin_project_name
    ]
    msg += get_tags(tags)

    send_message(msg)

def send_update_system_notification(project_name, project_release_version, project_release_type, organization_key):    
    msg = ""
    msg += get_title(project_name, project_release_version, project_release_type)
    msg += "\n"
    
    links = [
        ( "updater", "{}/{}/{}/info.html".format("https://plugin.evosoft.dev/organizations", organization_key, "updater") ),
        ( "gitlab", "https://gitlab.evosoft.xyz/reklama/iiko-integrations/version_control/update-system" ),
        ( "sentry", "https://sentry.evosoft.xyz/organizations/evosoft/projects/update-system" ),
        ( "sonar", "https://sonarqube.evosoft.xyz/dashboard?id=update-system" ),
    ]
    msg += get_links(links)
    msg += "\n"

    tags = [
        project_name,
        project_release_type,
        organization_key
    ]
    msg += get_tags(tags)

    send_message(msg)

if __name__ == '__main__':
    # send_plugin_notification("project_name", "project_release_version", "project_release_type", "project_type")
    # send_updater_notification("updater", "project_release_version", "project_release_type", "project_name")

    pass
